/*
 * See the README file for copyright information and how to reach the author.
 */

#include "i18n.h"

const tI18nPhrase Phrases[] = {
  { "Extended recordings menu",
    "Erweitertes Aufzeichnungs-Men",
    "",
    "",
    "",
    "",
    "Menu enregistrement tandu",
    "",
    "Laajennettu tallennevalikko",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "Rozen menu nahrvek",
  },
  { "Button$Open",
    "ffnen",
    "",
    "",
    "",
    "",
    "Ouvrir",
    "",
    "Avaa",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "Otevt",
  },
  { "Button$Back",
    "Zurck",
    "",
    "",
    "",
    "",
    "Retour",
    "",
    "Takaisin",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "Zpt",
  },
  { "Button$Cancel",
    "Abbrechen",
    "",
    "",
    "",
    "",
    "Interrompre",
    "",
    "Peruuta",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "Zruit",
  },
  { "Button$Play",
    "Wiedergabe",
    "",
    "",
    "",
    "",
    "Montrer",
    "",
    "Toista",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "Pehrt",
  },
  { "Button$Commands",
    "Befehle",
    "",
    "",
    "",
    "",
    "Commande",
    "",
    "Komennot",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "Pkazy",
  },
  { "Button$Rewind",
    "Anfang",
    "",
    "",
    "",
    "",
    "Dbut",
    "",
    "Alkuun",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "Na zatek",
  },
  { "Button$Create",
    "Anlegen",
    "",
    "",
    "",
    "",
    "Crer",
    "",
    "Luo",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "Vytvoit",
  },
  { "Button$Edit",
    "Editieren",
    "",
    "",
    "",
    "",
    "diter",
    "",
    "Muokkaa",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "Editovat",
  },
  { "Button$Rename",
    "Umbenennen",
    "",
    "",
    "",
    "",
    "Renommer",
    "",
    "Nime",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "Pejmenovat",
  },
  { "Button$Move",
    "Verschieben",
    "",
    "",
    "",
    "",
    "Dplacer",
    "",
    "Siirr",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "Pesunout",
  },
  { "Button$Delete",
    "Lschen",
    "",
    "",
    "",
    "",
    "Effacer",
    "",
    "Poista",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "Smazat",
  },
  { "Button$Info",
    "Info",
    "",
    "",
    "",
    "",
    "Info",
    "",
    "Tiedot",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "Info",
  },
  { "New folder",
    "Neues Verzeichnis",
    "",
    "",
    "",
    "",
    "Nouveau dossier",
    "",
    "Uusi kansio",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "Nov adres",
  },
  { "Rename",
    "Umbenennen",
    "",
    "",
    "",
    "",
    "Renommer",
    "",
    "Nime",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "Pejmenovat",
  },
  { "Show recording date",
    "Aufnahmedatum anzeigen",
    "",
    "",
    "",
    "",
    "Afiicher la date d'enregistrement",
    "",
    "Nyt tallenteen pivys",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "Zobrazit datum nahrvky",
  },
  { "Show recording time",
    "Aufnahmezeit anzeigen",
    "",
    "",
    "",
    "",
    "Afficher l'heure d'enregistrement",
    "",
    "Nyt tallenteen ajankohta",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "Zobrazit as nahrvky",
  },
  { "Show recording length",
    "Aufnahmelnge anzeigen",
    "",
    "",
    "",
    "",
    "Afficher la longeur de l'enregistrement",
    "",
    "Nyt tallenteen kesto",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "Zobrazit dlku nahrvky",
  },
  { "Hide main menu entry",
    "Hauptmeneintrag ausblenden",
    "",
    "",
    "",
    "",
    "Menu Enregistrement tandu invisible",
    "",
    "Piilota valinta pvalikosta",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "Skrt poloku v hlavnm menu",
  },
  { "Replace original recordings menu",
    "Originales Aufzeichnungsmen ersetzen",
    "",
    "",
    "",
    "",
    "Remplacer le nenu original Enregistrement",
    "",
    "Korvaa alkuperinen tallennevalikko",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "Nahradit originln menu nahrvek",
  },
  { "Show alternative to new marker",
    "Alternative zu Neu-Marker anzeigen",
    "",
    "",
    "",
    "",
    "Afficher les nouveaux symbols alternatifs",
    "",
    "Merkitse uudet tallenteet symbolilla",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "Zobrazit alternativu k novm znakm",
  },
  { "Please insert DVD %s",
    "Bitte DVD %s einlegen",
    "",
    "",
    "",
    "",
    "Mettez le DVD %s dans le lecteur",
    "",
    "Laita DVD %s asemaan",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "Vlote prosm DVD %s",
  },
  { "Error while mounting DVD!",
    "Fehler beim Einhngen der DVD!",
    "",
    "",
    "",
    "",
    "Erreur lors du montage du DVD!",
    "",
    "DVD:n avaaminen eponnistui!",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "Chyba bhem pipojovn DVD!",
  },
  { "Recording not found on DVD!",
    "Aufzeichnung auf DVD nicht gefunden!",
    "",
    "",
    "",
    "",
    "Il n'y a pas d'enregistrement sur le DVD!",
    "",
    "Tallennetta ei lydy DVD:lt!",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "Nahrvka nebyla na DVD nalezena!",
  },
  { "Script 'dvdarchive.sh' not found!",
    "Skript 'dvdarchive.sh' wurde nicht gefunden!",
    "",
    "",
    "",
    "",
    "Impossible de trouver le script 'dvdarchive.sh'!",
    "",
    "'dvdarchive.sh'-skripti ei lydet!",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "Skript 'dvdarchive.sh' nebyl nalezen!",
  },
  { "[base dir]",
    "[Stammverzeichnis]",
    "",
    "",
    "",
    "",
    "[Dossier racine]",
    "",
    "[juurihakemisto]",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "[zkladn adres]",
  },
  { "No DVD in drive!",
    "Keine DVD im Laufwerk!",
    "",
    "",
    "",
    "",
    "Pas de DVD dans le lecteur!",
    "",
    "Asemassa ei ole DVD-levy!",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "V jednotce nen DVD!",
  },
  { "Error while linking [0-9]*.vdr!",
    "Fehler beim Anlegen der Symlinks [0-9]*.vdr!",
    "",
    "",
    "",
    "",
    "Erreur lors de la cration des racourcis [0-9]*.vdr!",
    "",
    "Tiedostojen [0-9]*.vdr linkittminen eponnistui!",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "Chyba pi spojovn [0-9]*.vdr!",
  },
  { "sudo or mount --bind / umount error (vfat system)",
    "sudo oder mount --bind / umount Fehler (VFAT-System)",
    "",
    "",
    "",
    "",
    "Erreur sudo ou mount --bind / umount (Systeme VFAT)",
    "",
    "Sudo tai mount --bind / umount -komento eponnistui (VFAT)!",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "sudo nebo mount --bind / umount selhal (VFAT-systm)",
  },
  { "Details",
    "Details",
    "",
    "",
    "",
    "",
    "Dtails",
    "",
    "Listiedot",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "Detaily",
  },
  { "DVD plugin is not installed!",
    "Das DVD-Plugin ist nicht installiert!",
    "",
    "",
    "",
    "",
    "Le plugin DVD n'est pas install!",
    "",
    "DVD-laajennosta ei lydy!",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "Modul DVD nen nainstalovn!",
  },
  { "Invalid filename!",
    "Ungltiger Dateiname!",
    "",
    "",
    "",
    "",
    "Nom de fichiers n'est pas valide'",
    "",
    "Virheellinen tiedoston nimi!",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "Chybn jmno souboru!",
  },
  { "Moving into own sub-directory not allowed!",
    "Verschieben in eigenes Unterverzeichnis nicht erlaubt!",
    "",
    "",
    "",
    "",
    "Dplacer dans le sous-dossier propre, n'est pas possible!",
    "",
    "Siirto omaan alihakemistoon ei ole sallittu!",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "Pesun do vlastnho podadrese nen povolen!",
  },
  { "Sort by name",
    "Sortieren nach Namen",
    "",
    "",
    "",
    "",
    "Triage selon le nom",
    "",
    "Tallenteet jrjestetn nimen mukaan",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "Tdit podle jmna",
  },
  { "Sort by date",
    "Sortieren nach Datum",
    "",
    "",
    "",
    "",
    "Triage selon date",
    "",
    "Tallenteet jrjestetn pivmrn mukaan",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "Tdit podle data",
  },
  { "Show nr. of new recordings of a directory",
    "Anzahl der neuen Aufz. eines Ordners anzeigen",
    "",
    "",
    "",
    "",
    "Afficher le nombre de nouveaux enregistrements dans les dossiers",
    "",
    "Nyt uusien tallenteiden lukumr",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "Zobrazovat poet novch nahrvek v adresi",
  },
  { "Sorting",
    "Sortierung",
    "",
    "",
    "",
    "",
    "Triage",
    "",
    "Jrjestys",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "Tdn",
  },
  { "ascending",
    "aufsteigend",
    "",
    "",
    "",
    "",
    "montant",
    "",
    "nouseva",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "vzestupn",
  },
  { "descending",
    "absteigend",
    "",
    "",
    "",
    "",
    "descendant",
    "",
    "laskeva",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "sestupn",
  },
  { "Jump to last replayed recording",
    "Springe zur zuletzt abgespielten Aufzeichnung",
    "",
    "",
    "",
    "",
    "Retour au dernier enregistrement lu",
    "",
    "Siirry viimeksi toistettuun tallenteeseen",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "Skoit na posledn pehrvanou nahrvku",
  },
  { "Call plugin after playback",
    "Nach Wiedergabe Plugin aufrufen",
    "",
    "",
    "",
    "",
    "Aprs la lecture dmarer le plugin",
    "",
    "Avaa laajennos toiston loputtua",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "Nvrat do modulu po ukonen pehrvn",
  },
  { "Move recordings in progress",
    "Es werden Aufzeichungen verschoben",
    "",
    "",
    "",
    "",
    "Enregistrements en cours de dplacement",
    "",
    "Tallenteiden siirto kynniss",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "Probh pesouvn nahrvek",
  },
  { "Limit bandwidth for move recordings",
    "Bandbreite beim Verschieben begrenzen",
    "",
    "",
    "",
    "",
    "Limiter la bande passante lors du dplacement",
    "",
    "Rajoita tallenteiden siirtokaistaa",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "Omezit rychlost pro pesun nahrvek",
  },
  { "Target filesystem filled- try anyway?",
    "Zielpartition voll - trotzdem versuchen?",
    "",
    "",
    "",
    "",
    "La partition de dstination est pleine - essayer tout de mme?",
    "",
    "Kohdepartitio tynn - yritetnk silti?",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "Clov oddl je pln - zkusit znovu?",
  },
  { "Path",
    "Pfad",
    "",
    "",
    "",
    "",
    "Chemin",
    "",
    "Polku",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "Cesta",
  },
  { "Size",
    "Gre",
    "",
    "",
    "",
    "",
    "Taille",
    "",
    "Koko",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "Velikost",
  },
  { "Use VDR's recording info menu",
    "VDRs Aufzeichnungs-Info-Men benutzen",
    "",
    "",
    "",
    "",
    "Utiliser le menu info enregistrement de VDR",
    "",
    "Kyt alkuperist tallenteen tiedot -valikkoa",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "Pouvat info menu nahrvek VDR",
  },
  { "Added recording to cutter queue",
    "Aufzeichnung der Schnitt-Warteschlange hinzugefgt",
    "",
    "",
    "",
    "",
    "Enregistrement ajout  la file d'attente de dcoupe",
    "",
    "Tallenne on listty leikkausjonoon",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "Nahrvka pidna do stihov fronty",
  },
  { "Recording already in cutter queue!",
    "Aufzeichnung bereits in Schnitt-Warteschlange",
    "",
    "",
    "",
    "",
    "L'enregistrement est dj dans la queue d'attente dcoupe!",
    "",
    "Tallenne on jo leikkausjonossa!",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "Nahrvka je ji ve stihov front!",
  },
  { "Cutter queue not empty",
    "Schnitt-Warteschlange nicht leer",
    "",
    "",
    "",
    "",
    "Queue d'attente dcoupe n'est pas vide",
    "",
    "Leikkausjono ei ole tyhj",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "Stihov fronta nen przdn",
  },
  { "Move recordings in progress",
    "Es werden Aufzeichnungen verschoben",
    "",
    "",
    "",
    "",
    "Des enregistrements sont en dplacement",
    "",
    "Tallenteiden siirto kynniss",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "Probh pesouvn nahrvek",
  },
  { "Cancel moving?",
    "Verschieben abbrechen?",
    "",
    "",
    "",
    "",
    "Interrompre le dplacement?",
    "",
    "Peruutetaanko siirto?",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "Peruit pesouvn?",
  },
  { "Patch font",
    "Font patchen",
    "",
    "",
    "",
    "",
    "Patch des police",
    "",
    "Kyt paikattua kirjasinta",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "Upravit font",
  },
  { "Show free disk space for each file system",
    "Freien Speicherplatz fr jede Partition anzeigen",
    "",
    "",
    "",
    "",
    "Afficher la place libre de chaque partition",
    "",
    "Nyt vapaa levytila jokaisella tiedostojrjestelmll",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "Zobrazit voln msto pro kad souborov systm",
  },
  { "Can't get filesystem information",
    "Kann Dateisysteminformationen nicht ermitteln",
    "",
    "",
    "",
    "",
    "Impossible de dterminer les informations du systme de fichiers",
    "",
    "Tiedostojrjestelmn tietojen lukeminen eponnistui",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "Nelze zskat informace o souborovm systmy",
  },
  { "Rename/Move failed!",
    "Umbenennen/Verschieben fehlgeschlagen!",
    "",
    "",
    "",
    "",
    "Renommer/dplacer  chou!",
    "",
    "Nimeminen/siirto eponnistui!",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "Pejmenovn/pesun selhal!",
  },
  { "Use cutter queue",
    "Schnittwarteschlange benutzen",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
    "",
  },
  { NULL }
  };

